# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cxmate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cxmate.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x0c\x63xmate.proto\x12\x05proto\"\xb9\x08\n\x0eNetworkElement\x12\r\n\x05label\x18\x01 \x01(\t\x12%\n\tparameter\x18\x02 \x01(\x0b\x32\x10.proto.ParameterH\x00\x12\x0e\n\x04json\x18\x03 \x01(\tH\x00\x12\x1b\n\x04node\x18\x04 \x01(\x0b\x32\x0b.proto.NodeH\x00\x12\x1b\n\x04\x65\x64ge\x18\x05 \x01(\x0b\x32\x0b.proto.EdgeH\x00\x12-\n\rnodeAttribute\x18\x06 \x01(\x0b\x32\x14.proto.NodeAttributeH\x00\x12-\n\redgeAttribute\x18\x07 \x01(\x0b\x32\x14.proto.EdgeAttributeH\x00\x12\x33\n\x10networkAttribute\x18\x08 \x01(\x0b\x32\x17.proto.NetworkAttributeH\x00\x12\x39\n\x13\x43\x61rtesianCoordinate\x18\t \x01(\x0b\x32\x1a.proto.CartesianCoordinateH\x00\x12!\n\x07\x63yGroup\x18\n \x01(\x0b\x32\x0e.proto.CyGroupH\x00\x12\x1f\n\x06\x63yView\x18\x0b \x01(\x0b\x32\r.proto.CyViewH\x00\x12\x33\n\x10\x63yVisualProperty\x18\x0c \x01(\x0b\x32\x17.proto.CyVisualPropertyH\x00\x12\x35\n\x11\x63yHiddenAttribute\x18\r \x01(\x0b\x32\x18.proto.CyHiddenAttributeH\x00\x12\x35\n\x11\x63yNetworkRelation\x18\x0e \x01(\x0b\x32\x18.proto.CyNetworkRelationH\x00\x12+\n\x0c\x63ySubNetwork\x18\x0f \x01(\x0b\x32\x13.proto.CySubNetworkH\x00\x12-\n\rcyTableColumn\x18\x10 \x01(\x0b\x32\x14.proto.CyTableColumnH\x00\x12\'\n\nndexStatus\x18\x11 \x01(\x0b\x32\x11.proto.NdexStatusH\x00\x12#\n\x08\x63itation\x18\x12 \x01(\x0b\x32\x0f.proto.CitationH\x00\x12-\n\rnodeCitations\x18\x13 \x01(\x0b\x32\x14.proto.NodeCitationsH\x00\x12-\n\redgeCitations\x18\x14 \x01(\x0b\x32\x14.proto.EdgeCitationsH\x00\x12!\n\x07support\x18\x15 \x01(\x0b\x32\x0e.proto.SupportH\x00\x12\x31\n\x0fnodeSupportance\x18\x16 \x01(\x0b\x32\x16.proto.NodeSupportanceH\x00\x12\x31\n\x0f\x65\x64geSupportance\x18\x17 \x01(\x0b\x32\x16.proto.EdgeSupportanceH\x00\x12+\n\x0c\x66unctionTerm\x18\x18 \x01(\x0b\x32\x13.proto.FunctionTermH\x00\x12)\n\x0breifiedEdge\x18\x19 \x01(\x0b\x32\x12.proto.ReifiedEdgeH\x00\x42\t\n\x07\x65lement\"\x90\x01\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x15\n\x0bstringValue\x18\x03 \x01(\tH\x00\x12\x16\n\x0c\x62ooleanValue\x18\x04 \x01(\x08H\x00\x12\x16\n\x0cintegerValue\x18\x05 \x01(\x03H\x00\x12\x15\n\x0bnumberValue\x18\x06 \x01(\x01H\x00\x42\x07\n\x05value\"?\n\x04Node\x12\x0f\n\x02id\x18\x01 \x01(\x03R\x03@id\x12\x0f\n\x04name\x18\x02 \x01(\tR\x01n\x12\x15\n\nrepresents\x18\x03 \x01(\tR\x01r\"Y\n\x04\x45\x64ge\x12\x0f\n\x02id\x18\x01 \x01(\x03R\x03@id\x12\x13\n\x08sourceId\x18\x02 \x01(\x03R\x01s\x12\x13\n\x08targetId\x18\x03 \x01(\x03R\x01t\x12\x16\n\x0binteraction\x18\x04 \x01(\tR\x01i\"l\n\rNodeAttribute\x12\x12\n\x06nodeId\x18\x01 \x01(\x03R\x02po\x12\x0f\n\x04name\x18\x02 \x01(\tR\x01n\x12\x10\n\x05value\x18\x03 \x01(\tR\x01v\x12\x0f\n\x04type\x18\x04 \x01(\tR\x01\x64\x12\x13\n\x08subnetId\x18\x05 \x01(\x03R\x01s\"l\n\rEdgeAttribute\x12\x12\n\x06\x65\x64geId\x18\x01 \x01(\x03R\x02po\x12\x0f\n\x04name\x18\x02 \x01(\tR\x01n\x12\x10\n\x05value\x18\x03 \x01(\tR\x01v\x12\x0f\n\x04type\x18\x04 \x01(\tR\x01\x64\x12\x13\n\x08subnetId\x18\x05 \x01(\x03R\x01s\"[\n\x10NetworkAttribute\x12\x0f\n\x04name\x18\x01 \x01(\tR\x01n\x12\x10\n\x05value\x18\x02 \x01(\tR\x01v\x12\x0f\n\x04type\x18\x03 \x01(\tR\x01\x64\x12\x13\n\x08subnetId\x18\x04 \x01(\x03R\x01s\"k\n\x13\x43\x61rtesianCoordinate\x12\x14\n\x06nodeId\x18\x01 \x01(\x03R\x04node\x12\x0c\n\x01x\x18\x02 \x01(\x01R\x01x\x12\x0c\n\x01y\x18\x03 \x01(\x01R\x01y\x12\x0c\n\x01z\x18\x04 \x01(\x01R\x01z\x12\x14\n\x06viewId\x18\x05 \x01(\x03R\x04view\"\xa5\x01\n\x07\x43yGroup\x12\x0f\n\x02id\x18\x01 \x01(\x03R\x03@id\x12\x12\n\x04view\x18\x02 \x01(\x03R\x04view\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x14\n\x05nodes\x18\x04 \x03(\x03R\x05nodes\x12$\n\rexternalEdges\x18\x05 \x03(\x03R\rexternal_edge\x12%\n\rinternalEdges\x18\x06 \x03(\x03R\x0einternal_edges\".\n\x06\x43yView\x12\x0f\n\x02id\x18\x01 \x01(\x03R\x03@id\x12\x13\n\x08subnetId\x18\x02 \x01(\x03R\x01s\"\xd5\x03\n\x10\x43yVisualProperty\x12\x1c\n\x05owner\x18\x01 \x01(\tR\rproperties_of\x12\x1b\n\x07ownerId\x18\x02 \x01(\x03R\napplies_to\x12\x12\n\x04view\x18\x04 \x01(\x03R\x04view\x12G\n\nproperties\x18\x05 \x03(\x0b\x32\'.proto.CyVisualProperty.PropertiesEntryR\nproperties\x12M\n\x0c\x64\x65pendencies\x18\x06 \x03(\x0b\x32).proto.CyVisualProperty.DependenciesEntryR\x0c\x64\x65pendencies\x12\x41\n\x08mappings\x18\x07 \x03(\x0b\x32%.proto.CyVisualProperty.MappingsEntryR\x08mappings\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x44\x65pendenciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMappingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\\\n\x11\x43yHiddenAttribute\x12\x0f\n\x04name\x18\x01 \x01(\tR\x01n\x12\x10\n\x05value\x18\x02 \x01(\tR\x01v\x12\x0f\n\x04type\x18\x03 \x01(\tR\x01\x64\x12\x13\n\x08subnetId\x18\x04 \x01(\x03R\x01s\"i\n\x11\x43yNetworkRelation\x12\x13\n\x08parentId\x18\x01 \x01(\x03R\x01p\x12\x12\n\x07\x63hildId\x18\x02 \x01(\x03R\x01\x63\x12\x17\n\x0crelationship\x18\x03 \x01(\tR\x01r\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\"K\n\x0c\x43ySubNetwork\x12\x0f\n\x02id\x18\x01 \x01(\x03R\x03@id\x12\x14\n\x05\x65\x64ges\x18\x02 \x03(\x03R\x05\x65\x64ges\x12\x14\n\x05nodes\x18\x03 \x03(\x03R\x05nodes\"k\n\rCyTableColumn\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner\x12\x1c\n\x08subnetId\x18\x04 \x01(\x03R\napplies_to\"\xf7\x01\n\nNdexStatus\x12\x16\n\x02id\x18\x01 \x01(\tR\nexternalId\x12\x1f\n\x08location\x18\x02 \x01(\tR\rndexServerURI\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner\x12\"\n\x0c\x63reationTime\x18\x04 \x01(\tR\x0c\x63reationTime\x12\x1a\n\x08readOnly\x18\x05 \x01(\x08R\x08readOnly\x12\x1e\n\nvisibility\x18\x06 \x01(\tR\nvisibility\x12\x1c\n\tedgeCount\x18\x07 \x01(\x03R\tedgeCount\x12\x1c\n\tnodeCount\x18\x08 \x01(\x03R\tnodeCount\"\xf2\x01\n\x08\x43itation\x12\x0f\n\x02id\x18\x01 \x01(\tR\x03@id\x12\x17\n\x05title\x18\x02 \x01(\tR\x08\x64\x63:title\x12#\n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0e\x64\x63:description\x12#\n\x0b\x63ontributor\x18\x04 \x01(\tR\x0e\x64\x63:contributor\x12!\n\nidentifier\x18\x05 \x01(\tR\rdc:identifier\x12\x15\n\x04type\x18\x06 \x01(\tR\x07\x64\x63:type\x12\x38\n\nattributes\x18\x07 \x03(\x0b\x32\x18.proto.CitationAttributeR\nattributes\"G\n\x11\x43itationAttribute\x12\x0f\n\x04name\x18\x01 \x01(\tR\x01n\x12\x10\n\x05value\x18\x02 \x01(\tR\x01v\x12\x0f\n\x04type\x18\x03 \x01(\tR\x01t\"@\n\rNodeCitations\x12\x18\n\x05nodes\x18\x01 \x03(\x03R\tcitations\x12\x15\n\tcitations\x18\x02 \x03(\x03R\x02po\"@\n\rEdgeCitations\x12\x18\n\x05\x65\x64ges\x18\x01 \x03(\x03R\tcitations\x12\x15\n\tcitations\x18\x02 \x03(\x03R\x02po\"\x85\x01\n\x07Support\x12\x0f\n\x02id\x18\x01 \x01(\x03R\x03@id\x12\x1c\n\ncitationId\x18\x02 \x01(\x03R\x08\x63itation\x12\x12\n\x04text\x18\x03 \x01(\tR\x04text\x12\x37\n\nattributes\x18\x04 \x03(\x0b\x32\x17.proto.SupportAttributeR\nattributes\"F\n\x10SupportAttribute\x12\x0f\n\x04name\x18\x01 \x01(\tR\x01n\x12\x10\n\x05value\x18\x02 \x01(\tR\x01v\x12\x0f\n\x04type\x18\x03 \x01(\tR\x01t\"@\n\x0fNodeSupportance\x12\x14\n\x05nodes\x18\x01 \x03(\x03R\x05nodes\x12\x17\n\x0bsupportance\x18\x02 \x03(\x03R\x02po\"@\n\x0f\x45\x64geSupportance\x12\x14\n\x05\x65\x64ges\x18\x01 \x03(\x03R\x05\x65\x64ges\x12\x17\n\x0bsupportance\x18\x02 \x03(\x03R\x02po\"P\n\x0c\x46unctionTerm\x12\x12\n\x06nodeId\x18\x01 \x01(\x03R\x02po\x12\x13\n\x08\x66unction\x18\x02 \x01(\tR\x01\x66\x12\x17\n\targuments\x18\x03 \x03(\tR\x04\x61rgs\"9\n\x0bReifiedEdge\x12\x14\n\x06\x65\x64geId\x18\x01 \x01(\x03R\x04\x65\x64ge\x12\x14\n\x06nodeId\x18\x02 \x01(\x03R\x04node2U\n\rcxMateService\x12\x44\n\x0eStreamNetworks\x12\x15.proto.NetworkElement\x1a\x15.proto.NetworkElement\"\x00(\x01\x30\x01\x62\x06proto3')
)




_NETWORKELEMENT = _descriptor.Descriptor(
  name='NetworkElement',
  full_name='proto.NetworkElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='proto.NetworkElement.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='proto.NetworkElement.parameter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='json', full_name='proto.NetworkElement.json', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='node', full_name='proto.NetworkElement.node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edge', full_name='proto.NetworkElement.edge', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nodeAttribute', full_name='proto.NetworkElement.nodeAttribute', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edgeAttribute', full_name='proto.NetworkElement.edgeAttribute', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='networkAttribute', full_name='proto.NetworkElement.networkAttribute', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='CartesianCoordinate', full_name='proto.NetworkElement.CartesianCoordinate', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cyGroup', full_name='proto.NetworkElement.cyGroup', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cyView', full_name='proto.NetworkElement.cyView', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cyVisualProperty', full_name='proto.NetworkElement.cyVisualProperty', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cyHiddenAttribute', full_name='proto.NetworkElement.cyHiddenAttribute', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cyNetworkRelation', full_name='proto.NetworkElement.cyNetworkRelation', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cySubNetwork', full_name='proto.NetworkElement.cySubNetwork', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cyTableColumn', full_name='proto.NetworkElement.cyTableColumn', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ndexStatus', full_name='proto.NetworkElement.ndexStatus', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='citation', full_name='proto.NetworkElement.citation', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nodeCitations', full_name='proto.NetworkElement.nodeCitations', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edgeCitations', full_name='proto.NetworkElement.edgeCitations', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='support', full_name='proto.NetworkElement.support', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nodeSupportance', full_name='proto.NetworkElement.nodeSupportance', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edgeSupportance', full_name='proto.NetworkElement.edgeSupportance', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='functionTerm', full_name='proto.NetworkElement.functionTerm', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reifiedEdge', full_name='proto.NetworkElement.reifiedEdge', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='element', full_name='proto.NetworkElement.element',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=24,
  serialized_end=1105,
)


_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='proto.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.Parameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='format', full_name='proto.Parameter.format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='proto.Parameter.stringValue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='booleanValue', full_name='proto.Parameter.booleanValue', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='integerValue', full_name='proto.Parameter.integerValue', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numberValue', full_name='proto.Parameter.numberValue', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='proto.Parameter.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1108,
  serialized_end=1252,
)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='proto.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.Node.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='@id'),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.Node.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='n'),
    _descriptor.FieldDescriptor(
      name='represents', full_name='proto.Node.represents', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='r'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1254,
  serialized_end=1317,
)


_EDGE = _descriptor.Descriptor(
  name='Edge',
  full_name='proto.Edge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.Edge.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='@id'),
    _descriptor.FieldDescriptor(
      name='sourceId', full_name='proto.Edge.sourceId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='s'),
    _descriptor.FieldDescriptor(
      name='targetId', full_name='proto.Edge.targetId', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='t'),
    _descriptor.FieldDescriptor(
      name='interaction', full_name='proto.Edge.interaction', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='i'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1319,
  serialized_end=1408,
)


_NODEATTRIBUTE = _descriptor.Descriptor(
  name='NodeAttribute',
  full_name='proto.NodeAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodeId', full_name='proto.NodeAttribute.nodeId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='po'),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.NodeAttribute.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='n'),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.NodeAttribute.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='v'),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.NodeAttribute.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='d'),
    _descriptor.FieldDescriptor(
      name='subnetId', full_name='proto.NodeAttribute.subnetId', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='s'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1410,
  serialized_end=1518,
)


_EDGEATTRIBUTE = _descriptor.Descriptor(
  name='EdgeAttribute',
  full_name='proto.EdgeAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edgeId', full_name='proto.EdgeAttribute.edgeId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='po'),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.EdgeAttribute.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='n'),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.EdgeAttribute.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='v'),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.EdgeAttribute.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='d'),
    _descriptor.FieldDescriptor(
      name='subnetId', full_name='proto.EdgeAttribute.subnetId', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='s'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1520,
  serialized_end=1628,
)


_NETWORKATTRIBUTE = _descriptor.Descriptor(
  name='NetworkAttribute',
  full_name='proto.NetworkAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.NetworkAttribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='n'),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.NetworkAttribute.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='v'),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.NetworkAttribute.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='d'),
    _descriptor.FieldDescriptor(
      name='subnetId', full_name='proto.NetworkAttribute.subnetId', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='s'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1630,
  serialized_end=1721,
)


_CARTESIANCOORDINATE = _descriptor.Descriptor(
  name='CartesianCoordinate',
  full_name='proto.CartesianCoordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodeId', full_name='proto.CartesianCoordinate.nodeId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='node'),
    _descriptor.FieldDescriptor(
      name='x', full_name='proto.CartesianCoordinate.x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='x'),
    _descriptor.FieldDescriptor(
      name='y', full_name='proto.CartesianCoordinate.y', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='y'),
    _descriptor.FieldDescriptor(
      name='z', full_name='proto.CartesianCoordinate.z', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='z'),
    _descriptor.FieldDescriptor(
      name='viewId', full_name='proto.CartesianCoordinate.viewId', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='view'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1723,
  serialized_end=1830,
)


_CYGROUP = _descriptor.Descriptor(
  name='CyGroup',
  full_name='proto.CyGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.CyGroup.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='@id'),
    _descriptor.FieldDescriptor(
      name='view', full_name='proto.CyGroup.view', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='view'),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.CyGroup.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='name'),
    _descriptor.FieldDescriptor(
      name='nodes', full_name='proto.CyGroup.nodes', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='nodes'),
    _descriptor.FieldDescriptor(
      name='externalEdges', full_name='proto.CyGroup.externalEdges', index=4,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='external_edge'),
    _descriptor.FieldDescriptor(
      name='internalEdges', full_name='proto.CyGroup.internalEdges', index=5,
      number=6, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='internal_edges'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1833,
  serialized_end=1998,
)


_CYVIEW = _descriptor.Descriptor(
  name='CyView',
  full_name='proto.CyView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.CyView.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='@id'),
    _descriptor.FieldDescriptor(
      name='subnetId', full_name='proto.CyView.subnetId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='s'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2000,
  serialized_end=2046,
)


_CYVISUALPROPERTY_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='proto.CyVisualProperty.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proto.CyVisualProperty.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.CyVisualProperty.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2367,
  serialized_end=2416,
)

_CYVISUALPROPERTY_DEPENDENCIESENTRY = _descriptor.Descriptor(
  name='DependenciesEntry',
  full_name='proto.CyVisualProperty.DependenciesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proto.CyVisualProperty.DependenciesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.CyVisualProperty.DependenciesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2418,
  serialized_end=2469,
)

_CYVISUALPROPERTY_MAPPINGSENTRY = _descriptor.Descriptor(
  name='MappingsEntry',
  full_name='proto.CyVisualProperty.MappingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proto.CyVisualProperty.MappingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.CyVisualProperty.MappingsEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2471,
  serialized_end=2518,
)

_CYVISUALPROPERTY = _descriptor.Descriptor(
  name='CyVisualProperty',
  full_name='proto.CyVisualProperty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='proto.CyVisualProperty.owner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='properties_of'),
    _descriptor.FieldDescriptor(
      name='ownerId', full_name='proto.CyVisualProperty.ownerId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='applies_to'),
    _descriptor.FieldDescriptor(
      name='view', full_name='proto.CyVisualProperty.view', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='view'),
    _descriptor.FieldDescriptor(
      name='properties', full_name='proto.CyVisualProperty.properties', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='properties'),
    _descriptor.FieldDescriptor(
      name='dependencies', full_name='proto.CyVisualProperty.dependencies', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='dependencies'),
    _descriptor.FieldDescriptor(
      name='mappings', full_name='proto.CyVisualProperty.mappings', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='mappings'),
  ],
  extensions=[
  ],
  nested_types=[_CYVISUALPROPERTY_PROPERTIESENTRY, _CYVISUALPROPERTY_DEPENDENCIESENTRY, _CYVISUALPROPERTY_MAPPINGSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2049,
  serialized_end=2518,
)


_CYHIDDENATTRIBUTE = _descriptor.Descriptor(
  name='CyHiddenAttribute',
  full_name='proto.CyHiddenAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.CyHiddenAttribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='n'),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.CyHiddenAttribute.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='v'),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.CyHiddenAttribute.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='d'),
    _descriptor.FieldDescriptor(
      name='subnetId', full_name='proto.CyHiddenAttribute.subnetId', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='s'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2520,
  serialized_end=2612,
)


_CYNETWORKRELATION = _descriptor.Descriptor(
  name='CyNetworkRelation',
  full_name='proto.CyNetworkRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parentId', full_name='proto.CyNetworkRelation.parentId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='p'),
    _descriptor.FieldDescriptor(
      name='childId', full_name='proto.CyNetworkRelation.childId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='c'),
    _descriptor.FieldDescriptor(
      name='relationship', full_name='proto.CyNetworkRelation.relationship', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='r'),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.CyNetworkRelation.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='name'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2614,
  serialized_end=2719,
)


_CYSUBNETWORK = _descriptor.Descriptor(
  name='CySubNetwork',
  full_name='proto.CySubNetwork',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.CySubNetwork.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='@id'),
    _descriptor.FieldDescriptor(
      name='edges', full_name='proto.CySubNetwork.edges', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='edges'),
    _descriptor.FieldDescriptor(
      name='nodes', full_name='proto.CySubNetwork.nodes', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='nodes'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2721,
  serialized_end=2796,
)


_CYTABLECOLUMN = _descriptor.Descriptor(
  name='CyTableColumn',
  full_name='proto.CyTableColumn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.CyTableColumn.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='name'),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.CyTableColumn.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='type'),
    _descriptor.FieldDescriptor(
      name='owner', full_name='proto.CyTableColumn.owner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='owner'),
    _descriptor.FieldDescriptor(
      name='subnetId', full_name='proto.CyTableColumn.subnetId', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='applies_to'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2798,
  serialized_end=2905,
)


_NDEXSTATUS = _descriptor.Descriptor(
  name='NdexStatus',
  full_name='proto.NdexStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.NdexStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='externalId'),
    _descriptor.FieldDescriptor(
      name='location', full_name='proto.NdexStatus.location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='ndexServerURI'),
    _descriptor.FieldDescriptor(
      name='owner', full_name='proto.NdexStatus.owner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='owner'),
    _descriptor.FieldDescriptor(
      name='creationTime', full_name='proto.NdexStatus.creationTime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='creationTime'),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='proto.NdexStatus.readOnly', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='readOnly'),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='proto.NdexStatus.visibility', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='visibility'),
    _descriptor.FieldDescriptor(
      name='edgeCount', full_name='proto.NdexStatus.edgeCount', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='edgeCount'),
    _descriptor.FieldDescriptor(
      name='nodeCount', full_name='proto.NdexStatus.nodeCount', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='nodeCount'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2908,
  serialized_end=3155,
)


_CITATION = _descriptor.Descriptor(
  name='Citation',
  full_name='proto.Citation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.Citation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='@id'),
    _descriptor.FieldDescriptor(
      name='title', full_name='proto.Citation.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='dc:title'),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.Citation.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='dc:description'),
    _descriptor.FieldDescriptor(
      name='contributor', full_name='proto.Citation.contributor', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='dc:contributor'),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='proto.Citation.identifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='dc:identifier'),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.Citation.type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='dc:type'),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='proto.Citation.attributes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='attributes'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3158,
  serialized_end=3400,
)


_CITATIONATTRIBUTE = _descriptor.Descriptor(
  name='CitationAttribute',
  full_name='proto.CitationAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.CitationAttribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='n'),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.CitationAttribute.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='v'),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.CitationAttribute.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='t'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3402,
  serialized_end=3473,
)


_NODECITATIONS = _descriptor.Descriptor(
  name='NodeCitations',
  full_name='proto.NodeCitations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='proto.NodeCitations.nodes', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='citations'),
    _descriptor.FieldDescriptor(
      name='citations', full_name='proto.NodeCitations.citations', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='po'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3475,
  serialized_end=3539,
)


_EDGECITATIONS = _descriptor.Descriptor(
  name='EdgeCitations',
  full_name='proto.EdgeCitations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edges', full_name='proto.EdgeCitations.edges', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='citations'),
    _descriptor.FieldDescriptor(
      name='citations', full_name='proto.EdgeCitations.citations', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='po'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3541,
  serialized_end=3605,
)


_SUPPORT = _descriptor.Descriptor(
  name='Support',
  full_name='proto.Support',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.Support.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='@id'),
    _descriptor.FieldDescriptor(
      name='citationId', full_name='proto.Support.citationId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='citation'),
    _descriptor.FieldDescriptor(
      name='text', full_name='proto.Support.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='text'),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='proto.Support.attributes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='attributes'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3608,
  serialized_end=3741,
)


_SUPPORTATTRIBUTE = _descriptor.Descriptor(
  name='SupportAttribute',
  full_name='proto.SupportAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.SupportAttribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='n'),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.SupportAttribute.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='v'),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SupportAttribute.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='t'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3743,
  serialized_end=3813,
)


_NODESUPPORTANCE = _descriptor.Descriptor(
  name='NodeSupportance',
  full_name='proto.NodeSupportance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='proto.NodeSupportance.nodes', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='nodes'),
    _descriptor.FieldDescriptor(
      name='supportance', full_name='proto.NodeSupportance.supportance', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='po'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3815,
  serialized_end=3879,
)


_EDGESUPPORTANCE = _descriptor.Descriptor(
  name='EdgeSupportance',
  full_name='proto.EdgeSupportance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edges', full_name='proto.EdgeSupportance.edges', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='edges'),
    _descriptor.FieldDescriptor(
      name='supportance', full_name='proto.EdgeSupportance.supportance', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='po'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3881,
  serialized_end=3945,
)


_FUNCTIONTERM = _descriptor.Descriptor(
  name='FunctionTerm',
  full_name='proto.FunctionTerm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodeId', full_name='proto.FunctionTerm.nodeId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='po'),
    _descriptor.FieldDescriptor(
      name='function', full_name='proto.FunctionTerm.function', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='f'),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='proto.FunctionTerm.arguments', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='args'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3947,
  serialized_end=4027,
)


_REIFIEDEDGE = _descriptor.Descriptor(
  name='ReifiedEdge',
  full_name='proto.ReifiedEdge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edgeId', full_name='proto.ReifiedEdge.edgeId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='edge'),
    _descriptor.FieldDescriptor(
      name='nodeId', full_name='proto.ReifiedEdge.nodeId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, json_name='node'),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4029,
  serialized_end=4086,
)

_NETWORKELEMENT.fields_by_name['parameter'].message_type = _PARAMETER
_NETWORKELEMENT.fields_by_name['node'].message_type = _NODE
_NETWORKELEMENT.fields_by_name['edge'].message_type = _EDGE
_NETWORKELEMENT.fields_by_name['nodeAttribute'].message_type = _NODEATTRIBUTE
_NETWORKELEMENT.fields_by_name['edgeAttribute'].message_type = _EDGEATTRIBUTE
_NETWORKELEMENT.fields_by_name['networkAttribute'].message_type = _NETWORKATTRIBUTE
_NETWORKELEMENT.fields_by_name['CartesianCoordinate'].message_type = _CARTESIANCOORDINATE
_NETWORKELEMENT.fields_by_name['cyGroup'].message_type = _CYGROUP
_NETWORKELEMENT.fields_by_name['cyView'].message_type = _CYVIEW
_NETWORKELEMENT.fields_by_name['cyVisualProperty'].message_type = _CYVISUALPROPERTY
_NETWORKELEMENT.fields_by_name['cyHiddenAttribute'].message_type = _CYHIDDENATTRIBUTE
_NETWORKELEMENT.fields_by_name['cyNetworkRelation'].message_type = _CYNETWORKRELATION
_NETWORKELEMENT.fields_by_name['cySubNetwork'].message_type = _CYSUBNETWORK
_NETWORKELEMENT.fields_by_name['cyTableColumn'].message_type = _CYTABLECOLUMN
_NETWORKELEMENT.fields_by_name['ndexStatus'].message_type = _NDEXSTATUS
_NETWORKELEMENT.fields_by_name['citation'].message_type = _CITATION
_NETWORKELEMENT.fields_by_name['nodeCitations'].message_type = _NODECITATIONS
_NETWORKELEMENT.fields_by_name['edgeCitations'].message_type = _EDGECITATIONS
_NETWORKELEMENT.fields_by_name['support'].message_type = _SUPPORT
_NETWORKELEMENT.fields_by_name['nodeSupportance'].message_type = _NODESUPPORTANCE
_NETWORKELEMENT.fields_by_name['edgeSupportance'].message_type = _EDGESUPPORTANCE
_NETWORKELEMENT.fields_by_name['functionTerm'].message_type = _FUNCTIONTERM
_NETWORKELEMENT.fields_by_name['reifiedEdge'].message_type = _REIFIEDEDGE
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['parameter'])
_NETWORKELEMENT.fields_by_name['parameter'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['json'])
_NETWORKELEMENT.fields_by_name['json'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['node'])
_NETWORKELEMENT.fields_by_name['node'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['edge'])
_NETWORKELEMENT.fields_by_name['edge'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['nodeAttribute'])
_NETWORKELEMENT.fields_by_name['nodeAttribute'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['edgeAttribute'])
_NETWORKELEMENT.fields_by_name['edgeAttribute'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['networkAttribute'])
_NETWORKELEMENT.fields_by_name['networkAttribute'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['CartesianCoordinate'])
_NETWORKELEMENT.fields_by_name['CartesianCoordinate'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['cyGroup'])
_NETWORKELEMENT.fields_by_name['cyGroup'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['cyView'])
_NETWORKELEMENT.fields_by_name['cyView'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['cyVisualProperty'])
_NETWORKELEMENT.fields_by_name['cyVisualProperty'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['cyHiddenAttribute'])
_NETWORKELEMENT.fields_by_name['cyHiddenAttribute'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['cyNetworkRelation'])
_NETWORKELEMENT.fields_by_name['cyNetworkRelation'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['cySubNetwork'])
_NETWORKELEMENT.fields_by_name['cySubNetwork'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['cyTableColumn'])
_NETWORKELEMENT.fields_by_name['cyTableColumn'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['ndexStatus'])
_NETWORKELEMENT.fields_by_name['ndexStatus'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['citation'])
_NETWORKELEMENT.fields_by_name['citation'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['nodeCitations'])
_NETWORKELEMENT.fields_by_name['nodeCitations'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['edgeCitations'])
_NETWORKELEMENT.fields_by_name['edgeCitations'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['support'])
_NETWORKELEMENT.fields_by_name['support'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['nodeSupportance'])
_NETWORKELEMENT.fields_by_name['nodeSupportance'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['edgeSupportance'])
_NETWORKELEMENT.fields_by_name['edgeSupportance'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['functionTerm'])
_NETWORKELEMENT.fields_by_name['functionTerm'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_NETWORKELEMENT.oneofs_by_name['element'].fields.append(
  _NETWORKELEMENT.fields_by_name['reifiedEdge'])
_NETWORKELEMENT.fields_by_name['reifiedEdge'].containing_oneof = _NETWORKELEMENT.oneofs_by_name['element']
_PARAMETER.oneofs_by_name['value'].fields.append(
  _PARAMETER.fields_by_name['stringValue'])
_PARAMETER.fields_by_name['stringValue'].containing_oneof = _PARAMETER.oneofs_by_name['value']
_PARAMETER.oneofs_by_name['value'].fields.append(
  _PARAMETER.fields_by_name['booleanValue'])
_PARAMETER.fields_by_name['booleanValue'].containing_oneof = _PARAMETER.oneofs_by_name['value']
_PARAMETER.oneofs_by_name['value'].fields.append(
  _PARAMETER.fields_by_name['integerValue'])
_PARAMETER.fields_by_name['integerValue'].containing_oneof = _PARAMETER.oneofs_by_name['value']
_PARAMETER.oneofs_by_name['value'].fields.append(
  _PARAMETER.fields_by_name['numberValue'])
_PARAMETER.fields_by_name['numberValue'].containing_oneof = _PARAMETER.oneofs_by_name['value']
_CYVISUALPROPERTY_PROPERTIESENTRY.containing_type = _CYVISUALPROPERTY
_CYVISUALPROPERTY_DEPENDENCIESENTRY.containing_type = _CYVISUALPROPERTY
_CYVISUALPROPERTY_MAPPINGSENTRY.containing_type = _CYVISUALPROPERTY
_CYVISUALPROPERTY.fields_by_name['properties'].message_type = _CYVISUALPROPERTY_PROPERTIESENTRY
_CYVISUALPROPERTY.fields_by_name['dependencies'].message_type = _CYVISUALPROPERTY_DEPENDENCIESENTRY
_CYVISUALPROPERTY.fields_by_name['mappings'].message_type = _CYVISUALPROPERTY_MAPPINGSENTRY
_CITATION.fields_by_name['attributes'].message_type = _CITATIONATTRIBUTE
_SUPPORT.fields_by_name['attributes'].message_type = _SUPPORTATTRIBUTE
DESCRIPTOR.message_types_by_name['NetworkElement'] = _NETWORKELEMENT
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Edge'] = _EDGE
DESCRIPTOR.message_types_by_name['NodeAttribute'] = _NODEATTRIBUTE
DESCRIPTOR.message_types_by_name['EdgeAttribute'] = _EDGEATTRIBUTE
DESCRIPTOR.message_types_by_name['NetworkAttribute'] = _NETWORKATTRIBUTE
DESCRIPTOR.message_types_by_name['CartesianCoordinate'] = _CARTESIANCOORDINATE
DESCRIPTOR.message_types_by_name['CyGroup'] = _CYGROUP
DESCRIPTOR.message_types_by_name['CyView'] = _CYVIEW
DESCRIPTOR.message_types_by_name['CyVisualProperty'] = _CYVISUALPROPERTY
DESCRIPTOR.message_types_by_name['CyHiddenAttribute'] = _CYHIDDENATTRIBUTE
DESCRIPTOR.message_types_by_name['CyNetworkRelation'] = _CYNETWORKRELATION
DESCRIPTOR.message_types_by_name['CySubNetwork'] = _CYSUBNETWORK
DESCRIPTOR.message_types_by_name['CyTableColumn'] = _CYTABLECOLUMN
DESCRIPTOR.message_types_by_name['NdexStatus'] = _NDEXSTATUS
DESCRIPTOR.message_types_by_name['Citation'] = _CITATION
DESCRIPTOR.message_types_by_name['CitationAttribute'] = _CITATIONATTRIBUTE
DESCRIPTOR.message_types_by_name['NodeCitations'] = _NODECITATIONS
DESCRIPTOR.message_types_by_name['EdgeCitations'] = _EDGECITATIONS
DESCRIPTOR.message_types_by_name['Support'] = _SUPPORT
DESCRIPTOR.message_types_by_name['SupportAttribute'] = _SUPPORTATTRIBUTE
DESCRIPTOR.message_types_by_name['NodeSupportance'] = _NODESUPPORTANCE
DESCRIPTOR.message_types_by_name['EdgeSupportance'] = _EDGESUPPORTANCE
DESCRIPTOR.message_types_by_name['FunctionTerm'] = _FUNCTIONTERM
DESCRIPTOR.message_types_by_name['ReifiedEdge'] = _REIFIEDEDGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NetworkElement = _reflection.GeneratedProtocolMessageType('NetworkElement', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKELEMENT,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.NetworkElement)
  ))
_sym_db.RegisterMessage(NetworkElement)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETER,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.Parameter)
  ))
_sym_db.RegisterMessage(Parameter)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
  DESCRIPTOR = _NODE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.Node)
  ))
_sym_db.RegisterMessage(Node)

Edge = _reflection.GeneratedProtocolMessageType('Edge', (_message.Message,), dict(
  DESCRIPTOR = _EDGE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.Edge)
  ))
_sym_db.RegisterMessage(Edge)

NodeAttribute = _reflection.GeneratedProtocolMessageType('NodeAttribute', (_message.Message,), dict(
  DESCRIPTOR = _NODEATTRIBUTE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.NodeAttribute)
  ))
_sym_db.RegisterMessage(NodeAttribute)

EdgeAttribute = _reflection.GeneratedProtocolMessageType('EdgeAttribute', (_message.Message,), dict(
  DESCRIPTOR = _EDGEATTRIBUTE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.EdgeAttribute)
  ))
_sym_db.RegisterMessage(EdgeAttribute)

NetworkAttribute = _reflection.GeneratedProtocolMessageType('NetworkAttribute', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKATTRIBUTE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.NetworkAttribute)
  ))
_sym_db.RegisterMessage(NetworkAttribute)

CartesianCoordinate = _reflection.GeneratedProtocolMessageType('CartesianCoordinate', (_message.Message,), dict(
  DESCRIPTOR = _CARTESIANCOORDINATE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CartesianCoordinate)
  ))
_sym_db.RegisterMessage(CartesianCoordinate)

CyGroup = _reflection.GeneratedProtocolMessageType('CyGroup', (_message.Message,), dict(
  DESCRIPTOR = _CYGROUP,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CyGroup)
  ))
_sym_db.RegisterMessage(CyGroup)

CyView = _reflection.GeneratedProtocolMessageType('CyView', (_message.Message,), dict(
  DESCRIPTOR = _CYVIEW,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CyView)
  ))
_sym_db.RegisterMessage(CyView)

CyVisualProperty = _reflection.GeneratedProtocolMessageType('CyVisualProperty', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _CYVISUALPROPERTY_PROPERTIESENTRY,
    __module__ = 'cxmate_pb2'
    # @@protoc_insertion_point(class_scope:proto.CyVisualProperty.PropertiesEntry)
    ))
  ,

  DependenciesEntry = _reflection.GeneratedProtocolMessageType('DependenciesEntry', (_message.Message,), dict(
    DESCRIPTOR = _CYVISUALPROPERTY_DEPENDENCIESENTRY,
    __module__ = 'cxmate_pb2'
    # @@protoc_insertion_point(class_scope:proto.CyVisualProperty.DependenciesEntry)
    ))
  ,

  MappingsEntry = _reflection.GeneratedProtocolMessageType('MappingsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CYVISUALPROPERTY_MAPPINGSENTRY,
    __module__ = 'cxmate_pb2'
    # @@protoc_insertion_point(class_scope:proto.CyVisualProperty.MappingsEntry)
    ))
  ,
  DESCRIPTOR = _CYVISUALPROPERTY,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CyVisualProperty)
  ))
_sym_db.RegisterMessage(CyVisualProperty)
_sym_db.RegisterMessage(CyVisualProperty.PropertiesEntry)
_sym_db.RegisterMessage(CyVisualProperty.DependenciesEntry)
_sym_db.RegisterMessage(CyVisualProperty.MappingsEntry)

CyHiddenAttribute = _reflection.GeneratedProtocolMessageType('CyHiddenAttribute', (_message.Message,), dict(
  DESCRIPTOR = _CYHIDDENATTRIBUTE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CyHiddenAttribute)
  ))
_sym_db.RegisterMessage(CyHiddenAttribute)

CyNetworkRelation = _reflection.GeneratedProtocolMessageType('CyNetworkRelation', (_message.Message,), dict(
  DESCRIPTOR = _CYNETWORKRELATION,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CyNetworkRelation)
  ))
_sym_db.RegisterMessage(CyNetworkRelation)

CySubNetwork = _reflection.GeneratedProtocolMessageType('CySubNetwork', (_message.Message,), dict(
  DESCRIPTOR = _CYSUBNETWORK,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CySubNetwork)
  ))
_sym_db.RegisterMessage(CySubNetwork)

CyTableColumn = _reflection.GeneratedProtocolMessageType('CyTableColumn', (_message.Message,), dict(
  DESCRIPTOR = _CYTABLECOLUMN,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CyTableColumn)
  ))
_sym_db.RegisterMessage(CyTableColumn)

NdexStatus = _reflection.GeneratedProtocolMessageType('NdexStatus', (_message.Message,), dict(
  DESCRIPTOR = _NDEXSTATUS,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.NdexStatus)
  ))
_sym_db.RegisterMessage(NdexStatus)

Citation = _reflection.GeneratedProtocolMessageType('Citation', (_message.Message,), dict(
  DESCRIPTOR = _CITATION,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.Citation)
  ))
_sym_db.RegisterMessage(Citation)

CitationAttribute = _reflection.GeneratedProtocolMessageType('CitationAttribute', (_message.Message,), dict(
  DESCRIPTOR = _CITATIONATTRIBUTE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.CitationAttribute)
  ))
_sym_db.RegisterMessage(CitationAttribute)

NodeCitations = _reflection.GeneratedProtocolMessageType('NodeCitations', (_message.Message,), dict(
  DESCRIPTOR = _NODECITATIONS,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.NodeCitations)
  ))
_sym_db.RegisterMessage(NodeCitations)

EdgeCitations = _reflection.GeneratedProtocolMessageType('EdgeCitations', (_message.Message,), dict(
  DESCRIPTOR = _EDGECITATIONS,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.EdgeCitations)
  ))
_sym_db.RegisterMessage(EdgeCitations)

Support = _reflection.GeneratedProtocolMessageType('Support', (_message.Message,), dict(
  DESCRIPTOR = _SUPPORT,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.Support)
  ))
_sym_db.RegisterMessage(Support)

SupportAttribute = _reflection.GeneratedProtocolMessageType('SupportAttribute', (_message.Message,), dict(
  DESCRIPTOR = _SUPPORTATTRIBUTE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.SupportAttribute)
  ))
_sym_db.RegisterMessage(SupportAttribute)

NodeSupportance = _reflection.GeneratedProtocolMessageType('NodeSupportance', (_message.Message,), dict(
  DESCRIPTOR = _NODESUPPORTANCE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.NodeSupportance)
  ))
_sym_db.RegisterMessage(NodeSupportance)

EdgeSupportance = _reflection.GeneratedProtocolMessageType('EdgeSupportance', (_message.Message,), dict(
  DESCRIPTOR = _EDGESUPPORTANCE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.EdgeSupportance)
  ))
_sym_db.RegisterMessage(EdgeSupportance)

FunctionTerm = _reflection.GeneratedProtocolMessageType('FunctionTerm', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTIONTERM,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.FunctionTerm)
  ))
_sym_db.RegisterMessage(FunctionTerm)

ReifiedEdge = _reflection.GeneratedProtocolMessageType('ReifiedEdge', (_message.Message,), dict(
  DESCRIPTOR = _REIFIEDEDGE,
  __module__ = 'cxmate_pb2'
  # @@protoc_insertion_point(class_scope:proto.ReifiedEdge)
  ))
_sym_db.RegisterMessage(ReifiedEdge)


_CYVISUALPROPERTY_PROPERTIESENTRY.has_options = True
_CYVISUALPROPERTY_PROPERTIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CYVISUALPROPERTY_DEPENDENCIESENTRY.has_options = True
_CYVISUALPROPERTY_DEPENDENCIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CYVISUALPROPERTY_MAPPINGSENTRY.has_options = True
_CYVISUALPROPERTY_MAPPINGSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))

_CXMATESERVICE = _descriptor.ServiceDescriptor(
  name='cxMateService',
  full_name='proto.cxMateService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=4088,
  serialized_end=4173,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamNetworks',
    full_name='proto.cxMateService.StreamNetworks',
    index=0,
    containing_service=None,
    input_type=_NETWORKELEMENT,
    output_type=_NETWORKELEMENT,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CXMATESERVICE)

DESCRIPTOR.services_by_name['cxMateService'] = _CXMATESERVICE

try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities


  class cxMateServiceStub(object):
    """********** SERVICE DEFINITION **********

    cxMateService defines a cxMate compatible service implementation
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.StreamNetworks = channel.stream_stream(
          '/proto.cxMateService/StreamNetworks',
          request_serializer=NetworkElement.SerializeToString,
          response_deserializer=NetworkElement.FromString,
          )


  class cxMateServiceServicer(object):
    """********** SERVICE DEFINITION **********

    cxMateService defines a cxMate compatible service implementation
    """

    def StreamNetworks(self, request_iterator, context):
      """StreamNetworks transfers one or more networks to and from the service.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_cxMateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'StreamNetworks': grpc.stream_stream_rpc_method_handler(
            servicer.StreamNetworks,
            request_deserializer=NetworkElement.FromString,
            response_serializer=NetworkElement.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'proto.cxMateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetacxMateServiceServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """********** SERVICE DEFINITION **********

    cxMateService defines a cxMate compatible service implementation
    """
    def StreamNetworks(self, request_iterator, context):
      """StreamNetworks transfers one or more networks to and from the service.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetacxMateServiceStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """********** SERVICE DEFINITION **********

    cxMateService defines a cxMate compatible service implementation
    """
    def StreamNetworks(self, request_iterator, timeout, metadata=None, with_call=False, protocol_options=None):
      """StreamNetworks transfers one or more networks to and from the service.
      """
      raise NotImplementedError()


  def beta_create_cxMateService_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('proto.cxMateService', 'StreamNetworks'): NetworkElement.FromString,
    }
    response_serializers = {
      ('proto.cxMateService', 'StreamNetworks'): NetworkElement.SerializeToString,
    }
    method_implementations = {
      ('proto.cxMateService', 'StreamNetworks'): face_utilities.stream_stream_inline(servicer.StreamNetworks),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_cxMateService_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('proto.cxMateService', 'StreamNetworks'): NetworkElement.SerializeToString,
    }
    response_deserializers = {
      ('proto.cxMateService', 'StreamNetworks'): NetworkElement.FromString,
    }
    cardinalities = {
      'StreamNetworks': cardinality.Cardinality.STREAM_STREAM,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'proto.cxMateService', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
